@@ -18,6 +18,7 @@ from .generating import (
 )
 
 from .grouping import (
+    complete_chunks,
     group_by_terminator,
     pairwise_padded,
     partition,
@@ -34,6 +35,7 @@ from .parsing import (
 
 from .selecting import (
     retain_if,
+    retain_if_not_none,
     reject_if,
     reject_if_none,
     retain_truthy,
@@ -57,12 +59,17 @@ from .searching import (
     first_matching,
     nth_matching,
     duplicates,
+    run_delimited_range,
 )
 
 from .sequences import (
     concat,
     pop_n,
     replace_range,
+    append_unique,
+    prepend_unique,
+    insert_unique,
+    extend_unique,
 )
 
 from .combining import (
@@ -73,14 +80,18 @@ __all__ = [
     "alternate_with",
     "append",
     "append_if",
+    "append_unique",
+    "complete_chunks",
     "concat",
     "duplicates",
     "ensure_contains",
     "expand_numbered_list",
     "extend",
+    "extend_unique",
     "first_matching",
     "generate",
     "group_by_terminator",
+    "insert_unique",
     "join_with",
     "nth_matching",
     "one",
@@ -90,6 +101,7 @@ __all__ = [
     "pop_n",
     "prepend",
     "prepend_if",
+    "prepend_unique",
     "range_from_text",
     "reject_falsy",
     "reject_if",
@@ -99,7 +111,9 @@ __all__ = [
     "replace_range",
     "retain_falsy",
     "retain_if",
+    "retain_if_not_none",
     "retain_truthy",
+    "run_delimited_range",
     "separate_with",
     "single",
     "skip_while",
